@@ -4,10 +4,13 @@
 import Lifetime
 import StringIO
 import Testing.ZopeTestCase
-import Testing.ZopeTestCase.layer
+import Testing.ZopeTestCase.utils
+import gocept.fssyncz2
+import plone.testing
+import plone.testing.z2
+import plone.testing.zca
 import re
 import zope.fssync.snarf
-import Testing.ZopeTestCase.utils
 
 
 class Lines(StringIO.StringIO):
@@ -49,19 +52,33 @@ def grep(pattern, lines, sort=False):
     return ''.join(lines)
 
 
-class Zope2FunctionalLayer(object):
+class _ZCMLSandbox(plone.testing.zca.ZCMLSandbox):
+    """Layer which loads ZCML and resets TALES expressions on tear down.
+
+    CAUTION: Not to be used directly, use ZCMLLayer, see above.
+
+    """
+    defaultBases = [plone.testing.z2.STARTUP]
+
+
+class Zope2FunctionalLayer(_ZCMLSandbox,):
 
-    __bases__ = (Testing.ZopeTestCase.layer.ZopeLiteLayer,)
     __name__ = 'functional_layer'
+    PRODUCTS = ['Products.Five',
+                'Products.ZReST',
+                'Products.PythonScripts',
+                'Products.CookieUserFolder']
 
     def setUp(self):
-        Testing.ZopeTestCase.installProduct('Five')
-        Testing.ZopeTestCase.installProduct('ZReST')
-        Testing.ZopeTestCase.installProduct('PythonScripts')
-        Testing.ZopeTestCase.layer.ZopeLiteLayer.setUp()
+        super(Zope2FunctionalLayer, self).setUp()
+        with plone.testing.z2.zopeApp(self['zodbDB']) as app:
+            for product in self.PRODUCTS:
+                plone.testing.z2.installProduct(app, product)
 
 
-functional_layer = Zope2FunctionalLayer()
+functional_layer = Zope2FunctionalLayer(
+    None, 'gocept.fssyncz2:ZCML', __name__, 'ftesting.zcml',
+    gocept.fssyncz2)
 
 
 class Zope2ServerLayer(Zope2FunctionalLayer):
@@ -86,7 +103,9 @@ class Zope2ServerLayer(Zope2FunctionalLayer):
         Lifetime.shutdown(0, fast=1)
 
 
-server_layer = Zope2ServerLayer()
+server_layer = Zope2ServerLayer(
+    None, 'gocept.fssyncz2:ZCML', __name__, 'ftesting.zcml',
+    gocept.fssyncz2)
 
 
 # gocept.zodb.dbiterator
@@ -121,7 +140,7 @@ class FileStorageOIDs(object):
 
     def getOIDs(self):
         """Return an iterable of all oids."""
-        return self.storage._index.keys()
+        return self.storage.changes._data.keys()
 
 
 class DatabaseIterator(object):
